powered by
dekamer
Dataset containing relevant terminology for each theme of the dekamer dataset
The dataset contains the following information:
theme: a theme, corresponding to the question_theme_main field in the dekamer dataset
question_theme_main
term: a word which describes the theme
theme
n: a measure of information indicating how relevant the term is (frequency of occurrence)
data(dekamer_theme_terminology) str(dekamer_theme_terminology)
Run the code above in your browser using DataLab